@@ -38,7 +38,7 @@ class WeekdaySettings(LDict):
 class Weekdays(LDict):
     """Represents all weekdays."""
 
-    def __init__(self):
+    def __init__(self) -> dict:
         super().__init__()
 
         for day in list(calendar.day_name):
@@ -54,7 +54,7 @@ class Schedule(LDict):
         active: bool = True,
         auto_schedule_settings: dict = {},
         auto_schedule_enabled: bool | None = None,
-    ) -> None:
+    ) -> dict:
         """Initialize an empty primary or secondary schedule.
 
         Args:
